@@ -1,11 +1,11 @@
 use strict;
 use warnings;
 
-package Dist::Zilla::Plugin::Run; # git description: 0.036-4-gc4b067c
+package Dist::Zilla::Plugin::Run; # git description: 0.037-6-g9135d1f
 # ABSTRACT: Run external commands and code at specific phases of Dist::Zilla
 # KEYWORDS: plugin tool distribution build release run command shell execute
 
-our $VERSION = '0.037';
+our $VERSION = '0.038';
 
 #pod =head1 SYNOPSIS
 #pod
@@ -100,6 +100,12 @@ our $VERSION = '0.037';
 #pod When true, if the C<run> command returns a non-zero exit status or the C<eval>
 #pod command dies, the build will fail. Defaults to true.
 #pod
+#pod =head2 quiet
+#pod
+#pod When true, diagnostic messages are not printed (except in C<--verbose> mode).
+#pod
+#pod Defaults to false.
+#pod
 #pod =head1 CONVERSIONS
 #pod
 #pod The following conversions/format specifiers are defined
@@ -136,7 +142,7 @@ Dist::Zilla::Plugin::Run - Run external commands and code at specific phases of
 
 =head1 VERSION
 
-version 0.037
+version 0.038
 
 =head1 SYNOPSIS
 
@@ -231,6 +237,12 @@ Defaults to false.
 When true, if the C<run> command returns a non-zero exit status or the C<eval>
 command dies, the build will fail. Defaults to true.
 
+=head2 quiet
+
+When true, diagnostic messages are not printed (except in C<--verbose> mode).
+
+Defaults to false.
+
 =head1 CONVERSIONS
 
 The following conversions/format specifiers are defined
